#  EPEL 8.1, PHP 7.3

Name:       php-extras
Summary:    Additional PHP extensions from the standard PHP distribution
Version:    7.3.20
Release:    1%{?dist}
License:    PHP
URL:        https://www.php.net/
Source0:    https://www.php.net/distributions/php-%{version}.tar.xz

BuildRequires: php-devel >= 7.3
BuildRequires: php-pdo


%description
PHP is an HTML-embedded scripting language.

This package contains various additional extension for PHP, which
have not been included in the basic PHP package for RHEL.


%package -n php-imap
Summary:       A module for PHP applications that use IMAP

BuildRequires: krb5-devel, openssl-devel, libc-client-devel

Requires:      php(zend-abi) = %{php_zend_api}
Requires:      php(api) = %{php_core_api}

%description -n php-imap
The php-imap package module will add IMAP (Internet Message Access Protocol)
support to PHP. IMAP is a protocol for retrieving and uploading e-mail messages
on mail servers. PHP is an HTML-embedded scripting language. If you need IMAP
support for PHP applications, you will need to install this package.


%package -n php-tidy
Summary:       Standard PHP module provides tidy library support

BuildRequires: libtidy-devel

Requires:      php(zend-abi) = %{php_zend_api}
Requires:      php(api) = %{php_core_api}

%description -n php-tidy
The php-tidy package contains a dynamic shared object that will
add support for using the tidy library to PHP.


%package -n php-pdo-dblib
Summary:        PDO driver Microsoft SQL Server and Sybase databases

BuildRequires:  freetds-devel

Requires:       php(zend-abi) = %{php_zend_api}
Requires:       php(api) = %{php_core_api}
Requires:       php(pdo-abi) = %{php_pdo_api}

Provides:       php-pdo_dblib, php-pdo_dblib%{?_isa}

%description -n php-pdo-dblib
The php-pdo-dblib package contains a dynamic shared object
that implements the PHP Data Objects (PDO) interface to enable access from
PHP to Microsoft SQL Server and Sybase databases through the FreeTDS libary.


%package -n php-interbase
Summary: A module for PHP applications that use Interbase/Firebird databases

# for fb_config command
BuildRequires:  firebird-devel

Requires:       php(zend-abi) = %{php_zend_api}
Requires:       php(api) = %{php_core_api}
Requires:       php(pdo-abi) = %{php_pdo_api}

Provides:       php-firebird, php-firebird%{?_isa}
Provides:       php-pdo_firebird, php-pdo_firebird%{?_isa}

%description -n php-interbase
The php-interbase package contains a dynamic shared object that will add
database support through Interbase/Firebird to PHP.

InterBase is the name of the closed-source variant of this RDBMS that was
developed by Borland/Inprise.

Firebird is a commercially independent project of C and C++ programmers,
technical advisors and supporters developing and enhancing a multi-platform
relational database management system based on the source code released by
Inprise Corp (now known as Borland Software Corp) under the InterBase Public
License.


%package -n php-pspell
Summary:       A module for PHP applications for using pspell interfaces

BuildRequires: aspell-devel >= 0.50.0

Requires:      php(zend-abi) = %{php_zend_api}
Requires:      php(api) = %{php_core_api}

%description -n php-pspell
The php-pspell package contains a dynamic shared object that will add
support for using the pspell library to PHP.


%package -n php-sodium
Summary: Wrapper for the Sodium cryptographic library

BuildRequires: pkgconfig(libsodium) >= 1.0.9

Requires:      php(zend-abi) = %{php_zend_api}
Requires:      php(api) = %{php_core_api}

Provides:      php-pecl(libsodium)         = %{version}
Provides:      php-pecl(libsodium)%{?_isa} = %{version}


%description -n php-sodium
The php-sodium package provides a simple,
low-level PHP extension for the libsodium cryptographic library.


%prep
%setup -q -n php-%{version}


%build
for mod in imap interbase pdo_dblib pdo_firebird pspell sodium tidy
do
    pushd ext/$mod

    %{_bindir}/phpize
    %configure \
       --with-libdir=%{_lib} \
       --with-imap=shared --with-kerberos --with-imap-ssl \
       --with-interbase=shared \
       --with-pdo-dblib=shared,%{_prefix} \
       --with-pdo-firebird=shared \
       --with-pspell=shared \
       --with-sodium=shared \
       --with-tidy=shared,%{_prefix} \
       --with-php-config=%{_bindir}/php-config

    make %{?_smp_mflags}

    popd
done


%check

for mod in imap interbase pdo_dblib pdo_firebird pspell sodium tidy
do
    : Minimal load test for $mod extension
    php -d extension=ext/$mod/modules/$mod.so -m | grep -i $mod
done

: skip known failed tests
rm ext/tidy/tests/020.phpt

: upstream test suite for extension without Database
fail=0
for mod in imap pspell sodium tidy
do
    pushd ext/$mod
    : Upstream tests for $mod extension
    make test NO_INTERACTION=1 || fail=1
    popd
done
exit $fail


%install
install -d %{buildroot}%{php_extdir}
install -d %{buildroot}%{php_inidir}

for mod in imap interbase pdo_dblib pdo_firebird pspell sodium tidy
do
    make -C ext/${mod} install INSTALL_ROOT=%{buildroot}

    cat > %{buildroot}%{php_inidir}/30-${mod}.ini <<EOF
; Enable ${mod} extension module
extension=${mod}
EOF
    cat > files.${mod} <<EOF
%{php_extdir}/${mod}.so
%config(noreplace) %{php_inidir}/30-${mod}.ini
EOF
done

cat files.pdo_firebird >>files.interbase


# Notice: PHP License in php-common pulled by each package

%files -n php-imap      -f files.imap
%files -n php-interbase -f files.interbase
%files -n php-pdo-dblib -f files.pdo_dblib
%files -n php-pspell    -f files.pspell
%files -n php-sodium    -f files.sodium
%files -n php-tidy      -f files.tidy


%changelog
* Tue Sep  8 2020 Remi Collet <rcollet@redhat.com> - 7.3.20-1
- rebase to 7.3.20

* Wed Feb  5 2020 Remi Collet <rcollet@redhat.com> - 7.3.5-1
- initial package for EPEL-8 and php:7.3
